@@ -324,6 +324,7 @@ class FriendlyTraceback:
             print("Internal problem in Friendly.")
             print("Please report this issue.")
             raise SystemExit
+        self.suppressed = ["       ... " + _("More lines not shown.") + " ..."]
         self.info = {"header": _("Python exception:")}
         self.info["_exc_type"] = etype
         self.info["_exc_instance"] = value
@@ -456,7 +457,7 @@ class FriendlyTraceback:
         * generic
         """
         self.info["generic"] = info_generic.get_generic_explanation(
-            self.tb_data.exception_name
+            self.tb_data.exception_type
         )
 
     def assign_location(self):
@@ -626,22 +627,10 @@ class FriendlyTraceback:
         _ = current_lang.translate
         if not hasattr(self, "message"):
             self.assign_message()
-        suppressed = ["\n       ... " + _("More lines not shown.") + " ...\n"]
-
         python_tb = [line.rstrip() for line in self.tb_data.formatted_tb]
 
         tb = self.create_traceback()
-        shortened_tb = tb[0:2] + suppressed + tb[-7:] if len(tb) > 10 else tb[:]
-        pattern = re.compile(r'File "(.*)", ')
-        temp = []
-        for line in shortened_tb:
-            match = re.search(pattern, line)
-            if match:
-                line = line.replace(
-                    match.group(1), path_utils.shorten_path(match.group(1))
-                )
-            temp.append(line)
-        shortened_tb = temp
+        shortened_tb = self.shorten(tb)
 
         header = "Traceback (most recent call last):"  # not included in records
         if python_tb[0].startswith(header):
@@ -659,16 +648,25 @@ class FriendlyTraceback:
                     continue
                 tb.append(line)
             if len(tb) > 12:
-                tb = tb[0:4] + suppressed + tb[-5:]
+                tb = tb[0:4] + self.suppressed + tb[-5:]
 
         exc = self.tb_data.value
+        chain_info = ""
+        short_chain_info = ""
         if exc.__cause__ or exc.__context__:
             chain_info = self.process_exception_chain(self.tb_data.exception_type, exc)
-        else:
-            chain_info = ""
+            parts = chain_info.split("\n\n")
+            # suppress line
+            temp = []
+            for part in parts:
+                part = "\n".join(self.shorten(part.split("\n")))
+                temp.append(part)
+            short_chain_info = "\n\n".join(temp)
 
         self.info["simulated_python_traceback"] = chain_info + "\n".join(tb) + "\n"
-        self.info["shortened_traceback"] = chain_info + "\n".join(shortened_tb) + "\n"
+        self.info["shortened_traceback"] = (
+            short_chain_info + "\n".join(shortened_tb) + "\n"
+        )
         self.info["original_python_traceback"] = (
             chain_info + "\n".join(python_tb) + "\n"
         )
@@ -677,6 +675,23 @@ class FriendlyTraceback:
         # skipcq: PYL-W0201
         self.tb_data.simulated_python_traceback = "\n".join(tb) + "\n"
 
+    def shorten(self, tb):
+        """Shortens a traceback (as list of lines)
+        by removing lines if it exceeds a certain length
+        and by using short synonyms for some common directories."""
+        _ = current_lang.translate
+        shortened_tb = tb[0:2] + self.suppressed + tb[-5:] if len(tb) > 12 else tb[:]
+        pattern = re.compile(r'^  File "(.*)", ')
+        temp = []
+        for line in shortened_tb:
+            match = re.search(pattern, line)
+            if match:
+                line = line.replace(
+                    match.group(1), path_utils.shorten_path(match.group(1))
+                )
+            temp.append(line)
+        return temp
+
     @staticmethod
     def process_exception_chain(etype, value):
         """Adds info about exceptions raised while treating other exceptions."""
