@@ -4,7 +4,7 @@ import re
 import sys
 
 
-from ..my_gettext import current_lang, no_information, please_report
+from ..my_gettext import current_lang, no_information, please_report, internal_error
 from ..utils import get_similar_words, list_to_string
 from ..path_info import path_utils
 from .. import info_variables
@@ -17,7 +17,7 @@ def get_cause(value, frame, tb_data):
         return _get_cause(value, frame, tb_data)
     except Exception:  # noqa
         debug_helper.log_error()
-        return None, None
+        return {"cause": internal_error(), "suggest": internal_error()}
 
 
 def _get_cause(value, frame, tb_data):
@@ -398,15 +398,13 @@ def use_synonym(obj_name, attribute, synonyms):
     _ = current_lang.translate
 
     hint = _("Did you mean `{attr}`?\n").format(attr=synonyms[0])
-
     cause = _("The object `{name}` has no attribute named `{attribute}`.\n").format(
         name=obj_name, attribute=attribute
     )
-
     if len(synonyms) == 1:
         cause += _(
             "However, `{attr}` is an attribute of `{name}` with a similar meaning.\n"
-        ).format(name=obj_name, attribute=attribute)
+        ).format(name=obj_name, attr=synonyms[0])
     else:
         cause += _(
             "However, `{name}` has the following attributes with similar meanings:\n"
