@@ -152,6 +152,9 @@ def too_many_values_to_unpack(message, frame, tb_data):
     return {"cause": cause}
 
 
+# TODO: complete the work below; note noqa to be removed
+
+
 @add_message_parser
 def invalid_literal_for_int(message, *_args):
     _ = current_lang.translate
@@ -162,7 +165,7 @@ def invalid_literal_for_int(message, *_args):
     base, value = int(match.group(1)), match.group(2).strip()
     if base == 10:
         try:
-            _value = float(value)
+            _value = float(value)  # noqa
             return _convert_to_float(value)
         except ValueError:
             pass
