@@ -54,6 +54,7 @@ class Statement:
         # From the traceback, we were previously able ot obtain the line
         # of code identified by Python as being problematic.
         self.bad_line = bad_line  # previously obtained from the traceback
+        # skipcq: PTC-W0052
         self.statement = bad_line  # temporary assignment
 
         # The following will be obtained using offset and bad_line
@@ -113,42 +114,44 @@ class Statement:
                     self.tokens = [token_utils.tokenize("Internal_error")[0]]
 
             self.statement = token_utils.untokenize(self.statement_tokens)
-            if self.filename.startswith("<friendly-console"):
-                if self.statement_brackets and not self.end_bracket:
-                    # We got an error flagged before we had the chance to close
-                    # brackets. Unclosed brackets are never a problem on their
-                    # own in a console session - so, we make sure to close
-                    # the brackets in order to be able to find the true cause
-                    # of the error
-                    # TODO: check this assumption; it appears to be incorrect
-                    add_token = ""
-                    brackets = self.statement_brackets.copy()
-                    while brackets:
-                        bracket = brackets.pop()
-                        if bracket == "(":
-                            add_token += ")"
-                        elif bracket == "[":
-                            add_token += "]"
-                        else:
-                            add_token += "}"
+            if (
+                self.filename.startswith("<friendly-console")
+                and self.statement_brackets
+                and not self.end_bracket
+            ):
+                # We got an error flagged before we had the chance to close
+                # brackets. Unclosed brackets should not be a problem on their
+                # own in a console session - so, we make sure to close
+                # the brackets in order to be able to find the true cause
+                # of the error
+                add_token = ""
+                brackets = self.statement_brackets.copy()
+                while brackets:
+                    bracket = brackets.pop()
+                    if bracket == "(":
+                        add_token += ")"
+                    elif bracket == "[":
+                        add_token += "]"
+                    else:
+                        add_token += "}"
 
-                    if self.tokens[0].string in [
-                        "class",
-                        "def",
-                        "if",
-                        "elif",
-                        "while",
-                        "for",
-                        "except",
-                        "with",
-                    ]:
-                        add_token += ":"
+                if self.tokens[0].string in [
+                    "class",
+                    "def",
+                    "if",
+                    "elif",
+                    "while",
+                    "for",
+                    "except",
+                    "with",
+                ]:
+                    add_token += ":"
 
-                    last_token = self.tokens[-1]
-                    last_token = last_token.copy()
-                    last_token.start_row += 1
-                    last_token.string = last_token.line = add_token
-                    self.tokens.append(last_token)
+                last_token = self.tokens[-1]
+                last_token = last_token.copy()
+                last_token.start_row += 1
+                last_token.string = last_token.line = add_token
+                self.tokens.append(last_token)
 
         elif "too many statically nested blocks" not in self.message:
             debug_helper.log("linenumber is None in source_info.Statement")
@@ -290,7 +293,7 @@ class Statement:
                 and previous_token is not None
                 and previous_token.string.strip()
                 and previous_token.start_row < token.start_row
-                and token.is_not_in(")]}")
+                and token.string not in ")]}"
             ):
                 break
             if (
@@ -302,31 +305,29 @@ class Statement:
                     break
                 # perhaps we have some unclosed bracket causing the error
                 # and we meant to start a new statement
-                elif token.is_in(
-                    [
-                        "async",
-                        "await",
-                        "class",
-                        "def",
-                        "return",
-                        "elif",
-                        "import",
-                        "try",
-                        "except",
-                        "finally",
-                        "with",
-                        "while",
-                        "yield",
-                        # ";",
-                    ]
+                if token.string in (
+                    "async",
+                    "await",
+                    "class",
+                    "def",
+                    "return",
+                    "elif",
+                    "import",
+                    "try",
+                    "except",
+                    "finally",
+                    "with",
+                    "while",
+                    "yield",
+                    # ";",
                 ):
                     break
-                elif self.bad_token == ":":
+
+                if self.bad_token == ":" or (
+                    token.string in ("if", "else", "for")
+                    and token.start_row > previous_row_non_space
+                ):
                     break
-                elif token.is_in(["if", "else", "for"]):
-                    if token.start_row > previous_row_non_space:
-                        # the keyword above likely starts a new statement
-                        break
             if token.string.strip():
                 previous_row_non_space = token.end_row
 
@@ -373,25 +374,27 @@ class Statement:
                 self.prev_token = token
 
             previous_token = token
-            if token.is_not_in("()[]}{"):
+            # careful to not accidentally include null strings as brackets
+            if not token.string or token.string not in "()[]}{":
                 continue
 
-            if token.is_in("([{"):
+            if token.string in "([{":
                 self.statement_brackets.append(token.string)
                 if self.bad_token is None or self.bad_token is token:
                     self.begin_brackets.append(token)
-            elif token.is_in(")]}"):
+            elif token.string in ")]}":
                 self.end_bracket = token
                 last_closing = token
+
                 if not self.statement_brackets:
                     break
-                else:
-                    open_bracket = self.statement_brackets.pop()
-                    if not matching_brackets(open_bracket, token.string):
-                        self.statement_brackets.append(open_bracket)
-                        break
-                    else:
-                        self.end_bracket = None
+
+                open_bracket = self.statement_brackets.pop()
+                if not matching_brackets(open_bracket, token.string):
+                    self.statement_brackets.append(open_bracket)
+                    break
+
+                self.end_bracket = None
 
         if self.statement_tokens:  # Protecting against EOF while parsing
             last_line = token_utils.untokenize(self.statement_tokens)
