@@ -162,6 +162,49 @@ def detect_backquote(statement):
     return {}
 
 
+@add_statement_analyzer
+def wrong_code_block(statement):
+    _ = current_lang.translate
+    if not (
+        statement.bad_token == ":"
+        and statement.nb_tokens == 2
+        and statement.prev_token.string in ("if", "for", "while", "class")
+    ):
+        return {}
+
+    word = statement.prev_token.string
+    if word in ("if", "while"):
+        hint = _("You forgot to add a condition.\n")
+        if word == "if":
+            cause = _(
+                "An `if` statement requires a condition:\n\n"
+                "    if condition:\n"
+                "        ...\n\n"
+            )
+        else:
+            cause = _(
+                "A `while` loop requires a condition:\n\n"
+                "    while condition:\n"
+                "        ...\n\n"
+            )
+    elif word == "for":
+        hint = _("A `for` loop requires at least 3 more terms.\n")
+        cause = _(
+            "A `for` loop is an iteration over a sequence:\n\n"
+            "    for element in sequence:\n"
+            "        ...\n\n"
+        )
+    else:
+        hint = _("A class needs a name.\n")
+        cause = _(
+            "A `class` statement requires a name:\n\n"
+            "    class SomeName:\n"
+            "        ...\n\n"
+        )
+
+    return {"cause": cause, "suggest": hint}
+
+
 @add_statement_analyzer
 def keyword_as_attribute(statement):
     """Will identify something like  obj.True ..."""
@@ -187,6 +230,7 @@ def keyword_as_attribute(statement):
 def confused_elif(statement):
     _ = current_lang.translate
     name = None
+    # skipcq: PYL-R1714
     if statement.bad_token == "elseif" or statement.prev_token == "elseif":
         name = "elseif"
     elif statement.bad_token == "if" and statement.prev_token == "else":
@@ -243,7 +287,7 @@ def misplaced_quote(statement):
             try:
                 fn(bad_string)  # Definitely not a word!
                 return {}
-            except Exception:
+            except Exception:  # noqa
                 pass
 
         hint = _("Perhaps you misplaced a quote.\n")
@@ -279,7 +323,9 @@ def detect_walrus(statement):
     if (prev == ":" and bad == "=" and bad.immediately_after(prev)) or (
         bad == ":" and next_token == "=" and bad.immediately_before(next_token)
     ):
-        hint = _("Your Python version does not support this f-string feature.\n")
+        hint = _(
+            "The augmented assignment operator is not allowed in Python version {version}.\n"
+        ).format(version=f"{sys.version_info.major}.{sys.version_info.minor}")
         cause = _(
             "You appear to be using the operator `:=`, sometimes called\n"
             "the walrus operator. This operator requires the use of\n"
@@ -308,7 +354,7 @@ def consecutive_operators(statement):
         hint = _("Did you mean to use `is` instead of `===`?\n")
         return {"cause": cause, "suggest": hint}
 
-    elif statement.bad_token == statement.prev_token:
+    if statement.bad_token == statement.prev_token:
         cause = _(
             "You cannot have write the same operator, `{op}`, twice in a row.\n"
             "Perhaps you wrote one of them by mistake\n"
@@ -365,8 +411,8 @@ def space_between_operators(statement):
     )
     if fixers.check_statement(new_statement):
         return {"cause": cause, "suggest": hint}
-    else:
-        return {"cause": cause + more_errors(), "suggest": hint}
+
+    return {"cause": cause + more_errors(), "suggest": hint}
 
 
 @add_statement_analyzer
@@ -420,8 +466,8 @@ def inverted_comparison_operators(statement):
     )
     if fixers.check_statement(new_statement):
         return {"cause": cause, "suggest": hint}
-    else:
-        return {"cause": cause + more_errors(), "suggest": hint}
+
+    return {"cause": cause + more_errors(), "suggest": hint}
 
 
 @add_statement_analyzer
@@ -447,46 +493,47 @@ def walrus_instead_of_equal(statement):
 def assign_instead_of_equal(statement):
     """Checks to see if an assignment sign, '=', has been used instead of
     an equal sign, '==', in an if, elif or while statement."""
-    # TODO: generalize this for other situations by checking that the proposed
-    # fix would work.
     _ = current_lang.translate
 
-    if not statement.bad_token == "=":
+    if statement.bad_token != "=":
         return {}
 
-    if not statement.first_token.is_in(["if", "elif", "while"]):
+    if statement.first_token.string not in ("if", "elif", "while"):
         return {}
 
     new_statement = fixers.replace_token(
         statement.statement_tokens, statement.bad_token, "=="
     )
     if not fixers.check_statement(new_statement):
-        # TODO: find a way to confirm that new error is later.
         debug_helper.log("Fix did not work in assign_instead_of_equal")
         additional_cause = more_errors()
     else:
         additional_cause = ""
 
-    if sys.version_info < (3, 8):
+    new_statement = fixers.replace_token(
+        statement.statement_tokens, statement.bad_token, ":="
+    )
+
+    if sys.version_info < (3, 8) or not fixers.check_statement(new_statement):
         hint = _("Perhaps you needed `==` instead of `=`.\n")
         cause = _(
-            "You used an assignment operator `=` instead of an equality operator `==`.\n"
+            "You likely used an assignment operator `=` instead of an equality operator `==`.\n"
         )
         return {"cause": cause + additional_cause, "suggest": hint}
+
+    if statement.next_token == ":":
+        hint = _("Perhaps you needed `:=` instead of `=:`.\n")
+        cause = _(
+            "You used an assignment operator `=` followed by `:`; perhaps you meant to use \n"
+            "the walrus operator `:=`.\n"
+        )
     else:
-        if statement.next_token == ":":
-            hint = _("Perhaps you needed `:=` instead of `=:`.\n")
-            cause = _(
-                "You used an assignment operator `=` followed by `:`; perhaps you meant to use \n"
-                "the walrus operator `:=`.\n"
-            )
-        else:
-            hint = _("Perhaps you needed `==` or `:=` instead of `=`.\n")
-            cause = _(
-                "You used an assignment operator `=`; perhaps you meant to use \n"
-                "an equality operator, `==`, or the walrus operator `:=`.\n"
-            )
-        return {"cause": cause + additional_cause, "suggest": hint}
+        hint = _("Perhaps you needed `==` or `:=` instead of `=`.\n")
+        cause = _(
+            "You used an assignment operator `=`; perhaps you meant to use \n"
+            "an equality operator, `==`, or the walrus operator `:=`.\n"
+        )
+    return {"cause": cause + additional_cause, "suggest": hint}
 
 
 @add_statement_analyzer
@@ -514,7 +561,7 @@ def print_as_statement(statement):
 @add_statement_analyzer
 def calling_python_or_pip(statement):
     _ = current_lang.translate
-    if not statement.first_token.is_in(["pip", "python"]):
+    if statement.first_token.string not in ("pip", "python"):
         return {}
 
     cause = _(
@@ -539,7 +586,7 @@ def calling_python_or_pip(statement):
 def dot_followed_by_bracket(statement):
     _ = current_lang.translate
 
-    if statement.bad_token.is_in("()[]{}") and statement.prev_token == ".":
+    if statement.bad_token.string in "()[]{}" and statement.prev_token == ".":
         cause = _("You cannot have a dot `.` followed by `{bracket}`.\n").format(
             bracket=statement.bad_token
         )
@@ -576,7 +623,7 @@ def invalid_double_star_operator(statement):
     if statement.bad_token == "**":
         cause = _(
             "The double star operator `**` is likely interpreted to mean that\n"
-            "dict unpacking is to be used which does not make sense here.\n"
+            "dict unpacking is to be used which is not allowed or does not make sense here.\n"
         )
         return {"cause": cause}
 
@@ -594,20 +641,18 @@ def missing_colon(statement):
     name = statement.first_token
     # Note: "async def" statements are transformed into "def" statements
     # prior to reaching this stage.
-    if name.is_not_in(
-        [
-            "class",
-            "def",
-            "if",
-            "elif",
-            "else",
-            "for",
-            "while",
-            "try",
-            "except",
-            "finally",
-            "with",
-        ]
+    if name.string not in (
+        "class",
+        "def",
+        "if",
+        "elif",
+        "else",
+        "for",
+        "while",
+        "try",
+        "except",
+        "finally",
+        "with",
     ):
         return {}
 
@@ -621,14 +666,15 @@ def missing_colon(statement):
 
     hint = _("Did you forget a colon `:`?\n")
 
-    if name.is_in(["for", "while"]):
+    if name.string in ("for", "while"):
         cause = _(
             "You wrote a `{for_while}` loop but\n"
             "forgot to add a colon `:` at the end\n"
             "\n"
         ).format(for_while=name)
         return {"cause": cause, "suggest": hint}
-    elif name.is_in(["def", "elif", "else", "except", "finally", "if", "try", "with"]):
+
+    if name.string in ("def", "elif", "else", "except", "finally", "if", "try", "with"):
         cause = _(
             "You wrote a statement beginning with\n"
             "`{name}` but forgot to add a colon `:` at the end.\n"
@@ -746,7 +792,6 @@ def invalid_name(statement):
     hint = _(
         "Perhaps you forgot a multiplication operator, `{first} * {second}`.\n"
     ).format(first=first, second=second)
-    cause = cause
 
     return {"cause": cause + hint + "\n" + note, "suggest": hint}
 
@@ -766,12 +811,13 @@ def debug_fstring(statement):
                 "in Python version 3.8. You are using version {version}.\n"
             ).format(version=f"{sys.version_info.major}.{sys.version_info.minor}")
             return {"cause": cause, "suggest": hint}
-        else:
-            cause = _(
-                "You are likely trying to assign a value within an f-string.\n"
-                "This is not allowed.\n"
-            )
-            return {"cause": cause}
+
+        cause = _(
+            "You are likely trying to assign a value within an f-string.\n"
+            "This is not allowed.\n"
+        )
+        return {"cause": cause}
+
     return {}
 
 
@@ -843,10 +889,11 @@ def lambda_with_paren(statement):
     for tok in tokens:
         if tok == "lambda":
             break
-        elif tok.is_identifier() or tok == ",":
+
+        if tok.is_identifier() or tok == ",":
             continue
-        else:
-            return {}
+
+        return {}
     else:
         return {}
 
@@ -864,8 +911,15 @@ def wrong_type_declaration(statement):
 
     if not statement.bad_token.is_identifier():
         return {}
-    if not statement.prev_token.is_in(
-        ["int", "float", "double", "var", "let", "str", "string", "complex"]
+    if statement.prev_token.string not in (
+        "int",
+        "float",
+        "double",
+        "var",
+        "let",
+        "str",
+        "string",
+        "complex",
     ):
         return {}
 
@@ -934,13 +988,18 @@ def missing_comma_before_string_in_dict(statement):
 def missing_in_with_for(statement):
     """Whenever we have a 'for' keyword, there should be a corresponding
     'in' keyword. Cases where 'in' have been misspelled are taken care below.
+    Note that 'in' could be used with 'if' and 'while' as well, but here
+    we only consider the simplest cases.
     """
     _ = current_lang.translate
 
+    nb_for = nb_in = 0
     for tok in statement.tokens[: statement.bad_token_index]:
         if tok == "for":
-            break
-    else:
+            nb_for += 1
+        elif tok == "in":
+            nb_in += 1
+    if nb_for == 0 or nb_in >= nb_for:
         return {}
 
     new_statement = fixers.replace_token(
@@ -959,6 +1018,31 @@ def missing_in_with_for(statement):
     return {}
 
 
+@add_statement_analyzer
+def missing_parens_for_range(statement):
+    _ = current_lang.translate
+
+    if statement.prev_token != "range" or statement.last_token != ":":
+        return {}
+
+    new_statement = fixers.replace_two_tokens(
+        statement.tokens,
+        statement.prev_token,
+        statement.prev_token.string + "(",
+        statement.last_token,
+        ")" + statement.last_token.string,
+    )
+    if fixers.check_statement(new_statement):
+        hint = _("Did you forget to write parenthesis?\n")
+        cause = _(
+            "It looks as though you forgot to use to use parenthesis with `range`.\n"
+            "Perhaps you meant:\n\n"
+            "    {new_statement}\n\n"
+        ).format(new_statement=new_statement)
+        return {"cause": cause, "suggest": hint}
+    return {}
+
+
 def _perhaps_misspelled_keyword(tokens, wrong):
     kwlist = list(keyword.kwlist)
     # Make sure we try possible typos first
@@ -1055,14 +1139,16 @@ def space_in_variable_name(statement):
 
     first_tokens = []
     for tok in statement.tokens:
-        if tok == "=" or tok == ":=":
+        if str(tok) in ("=", ":="):
             cause = _("You cannot have spaces in identifiers (variable names).\n")
             hint = _("Did you mean `{name}`?\n").format(name="_".join(first_tokens))
             return {"cause": cause, "suggest": hint}
-        elif not tok.is_identifier():
+
+        if not tok.is_identifier():
             return {}
-        else:
-            first_tokens.append(tok.string)
+
+        first_tokens.append(tok.string)
+
     return {}
 
 
@@ -1071,7 +1157,7 @@ def impossible_binary_fstring(statement):
     _ = current_lang.translate
     if (
         statement.bad_token.is_string()
-        and statement.prev_token.is_in(["bf", "fb"])
+        and statement.prev_token.string in ("bf", "fb")
         and statement.prev_token.immediately_before(statement.bad_token)
     ):
         hint = _("`bf` is an illegal string prefix.\n")
@@ -1093,8 +1179,8 @@ def _add_comma_or_operator(tokens, tok, comma_first=True):
             break
         new_statement = fixers.modify_token(tokens, tok, append=operator)
         if fixers.check_statement(new_statement):
-            if operator == "," and results:  # So that it prints correctly
-                operator = '","'
+            # if operator == "," and results:  # So that it prints correctly
+            #     operator = ','
             results.append((operator.strip(), new_statement))
     return results
 
@@ -1108,18 +1194,19 @@ def _comma_first_cause(bracket):
             "or between function arguments, \n"
             "before the position indicated by ^.\n"
         )
-    elif bracket == "[":
+
+    if bracket == "[":
         return _(
             "It is possible that you "
             "forgot a comma between items in a list\n"
             "before the position indicated by ^.\n"
         )
-    else:
-        return _(
-            "It is possible that you "
-            "forgot a comma between items in a set or dict\n"
-            "before the position indicated by ^.\n"
-        )
+
+    return _(
+        "It is possible that you "
+        "forgot a comma between items in a set or dict\n"
+        "before the position indicated by ^.\n"
+    )
 
 
 @add_statement_analyzer
@@ -1336,7 +1423,7 @@ def comprehension_condition_or_tuple(statement):
                     cause = cause_tuple
                     hint = _("Did you forget parentheses?\n")
                     return {"cause": cause, "suggest": hint}
-            else:
+            else:  # skipcq: PYL-W0120
                 return {}
     else:
         return {}
